Add option to use shared libarchive.
https://github.com/aseprite/aseprite/issues/1681
https://github.com/aseprite/aseprite/pull/2535
--- aseprite/CMakeLists.txt.orig	2023-11-28 16:57:22.000000000 -0600
+++ aseprite/CMakeLists.txt	2024-01-11 14:12:25.000000000 -0600
@@ -44,2 +44,3 @@
 option(USE_SHARED_ZLIB    "Use your installed copy of zlib" off)
+option(USE_SHARED_LIBARCHIVE "Use your installed copy of libarchive" off)
 option(USE_SHARED_LIBPNG  "Use your installed copy of libpng" off)
@@ -208,6 +209,17 @@
 endif()
 include_directories(${ZLIB_INCLUDE_DIRS})
 
+# libarchive
+if(USE_SHARED_LIBARCHIVE)
+  find_package(LibArchive REQUIRED)
+else()
+  set(LibArchive_FOUND)
+  set(LibArchive_LIBRARIES archive_static)
+  set(LibArchive_INCLUDE_DIRS $<BUILD_INTERFACE:${CMAKE_CURRENT_SOURCE_DIR}/libarchive/libarchive>)
+  add_definitions(-DLIBARCHIVE_STATIC)
+endif()
+include_directories(${LibArchive_INCLUDE_DIRS})
+
 # libpng
 if(USE_SHARED_LIBPNG)
   find_package(PNG REQUIRED)
--- aseprite/src/app/CMakeLists.txt.orig	2024-04-05 18:58:48.000000000 -0500
+++ aseprite/src/app/CMakeLists.txt	2024-04-16 12:11:21.000000000 -0500
@@ -95,9 +95,6 @@
   add_definitions(-DENABLE_PSD)
 endif()
 
-# libarchive definitions
-add_definitions(-DLIBARCHIVE_STATIC)
-
 ######################################################################
 # app-lib target
 
@@ -726,8 +723,8 @@
   ${ZLIB_LIBRARIES}
   ${FREETYPE_LIBRARIES}
   ${HARFBUZZ_LIBRARIES}
+  ${LibArchive_LIBRARIES}
   json11
-  archive_static
   fmt
   tinyexpr
   qoi)
--- aseprite/third_party/CMakeLists.txt.orig	2023-04-19 15:39:22.000000000 -0500
+++ aseprite/third_party/CMakeLists.txt	2023-04-19 20:20:45.000000000 -0500
@@ -126,6 +126,7 @@
 add_subdirectory(json11)
 
 # libarchive
+if(NOT USE_SHARED_LIBARCHIVE)
 set(ENABLE_WERROR OFF CACHE BOOL "Treat warnings as errors - default is ON for Debug, OFF otherwise.")
 set(ENABLE_TEST OFF CACHE BOOL "Enable unit and regression tests")
 set(ENABLE_COVERAGE OFF CACHE BOOL "Enable code coverage (GCC only, automatically sets ENABLE_TEST to ON)")
@@ -144,6 +145,7 @@
 add_subdirectory(libarchive)
 target_include_directories(archive_static INTERFACE
   $<BUILD_INTERFACE:${CMAKE_CURRENT_SOURCE_DIR}/libarchive/libarchive>)
+endif()
 
 # benchmark
 if(ENABLE_BENCHMARKS)
